package com.jboss.datagrid.test.notifications.listeners;

import org.infinispan.notifications.Listener;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryCreated;
import org.infinispan.notifications.cachelistener.annotation.DataRehashed;
import org.infinispan.notifications.cachelistener.annotation.TopologyChanged;
import org.infinispan.notifications.cachelistener.event.Event;
import org.infinispan.notifications.cachelistener.event.TopologyChangedEvent;

import java.util.concurrent.atomic.AtomicInteger;

/**
 * Custom listener for verifying all notificaitions.
 */
@Listener(sync=false)
public class DistributionListener {
   public AtomicInteger keyId = new AtomicInteger();
   public String nodeName;
   public Thread topologyThreadRunningNotif = null;
   public Thread threadRunningNotif;
   public boolean isRehashed= false;
   public boolean isTopologyChanged = false;

   public DistributionListener(final String nodeName) {
      this.nodeName = nodeName;
   }

   /**
    * Handling data creation event.
    * @param event
    */
   @CacheEntryCreated
   public void handleCreationAndModification(Event event) {
      if(event.isPre()) {
         threadRunningNotif = Thread.currentThread();
         keyId.getAndIncrement();
      }
   }

   /**
    * Handles data rehashed event.
    * @param evn
    */
   @DataRehashed
   public void handleDataRehash(Event evn) {
      if(evn.isPre()) {
         System.out.println("Data Rehashed on " + nodeName);
         isRehashed = true;
         threadRunningNotif = Thread.currentThread();
      }

   }

   /**
    * Handles cluster topology changed event.
    * @param event
    */
   @TopologyChanged
   public void handleTopologyChange(TopologyChangedEvent event) {
      if(!event.isPre()) {
         System.out.println("Topology changed." + nodeName);

         isTopologyChanged = true;
         topologyThreadRunningNotif = Thread.currentThread();
      }
   }
}