package com.jboss.datagrid.test.notifications.listeners;

import org.infinispan.notifications.Listener;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryCreated;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryInvalidated;
import org.infinispan.notifications.cachelistener.event.CacheEntryInvalidatedEvent;
import org.infinispan.notifications.cachelistener.event.Event;

import java.util.concurrent.atomic.AtomicInteger;

/**
 * Custom listener for handling notification events.
 */
@Listener(sync=false)
public class InvalidationListener {
   public AtomicInteger keyId = new AtomicInteger();
   public String nodeName;
   public Thread threadRunningNotif;
   public boolean isInvalidated = false;

   public InvalidationListener(final String nodeName) {
      this.nodeName = nodeName;
   }

   /**
    * Handles the entry created event.
    * @param event
    */
   @CacheEntryCreated
   public void handleCreationAndModification(Event event) {
      if(event.isPre()) {
         threadRunningNotif = Thread.currentThread();
         keyId.getAndIncrement();
      }
   }

   /**
    * Handles the entry invalidated event.
    * @param event
    */
   @CacheEntryInvalidated
   public void handleInvalidation(CacheEntryInvalidatedEvent event) {
      if (event.isPre()) {
         System.out.println("Data is invalidated.");
         isInvalidated = true;
         threadRunningNotif = Thread.currentThread();
         keyId.getAndIncrement();
      }
   }
}