package com.jboss.datagrid.test.notifications.utils;

import java.io.File;

import org.infinispan.configuration.cache.CacheMode;
import org.infinispan.configuration.cache.Configuration;
import org.infinispan.configuration.cache.ConfigurationBuilder;
import org.infinispan.configuration.global.GlobalConfiguration;
import org.infinispan.configuration.global.GlobalConfigurationBuilder;
import org.infinispan.manager.DefaultCacheManager;
import org.infinispan.remoting.transport.jgroups.JGroupsTransport;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.spec.WebArchive;

/**
 * Abstract class which contains all constants and with paths to configuration files, as well as it creates the basic
 * deployment with the common libraries. This class contains the common assertion methods which are used during tests.
 *
 * @author Anna Manukyan
 */
public class DeploymentBuilder {
   public static final String WAR_NAME = "test.war";
   public static final String TESTABLE_PACKAGE = "com.jboss.datagrid.test.notifications";

   /**
    * Creates the basic web archive with common libraries.
    *
    * @param warName the name of the war to be created.
    * @return the created web archive.
    */
   public static WebArchive createTestsWebArchive(final String warName) {
      WebArchive war = ShrinkWrap.create(WebArchive.class, warName)
            .addPackages(true, new String[]{TESTABLE_PACKAGE})
            .addAsResource(new File("target/test-classes/jgroups-tcp.xml"))
            .addAsWebInfResource(EmptyAsset.INSTANCE, "beans.xml");
      war.addAsLibraries(
            new File("target/test-libs/infinispan-core.jar"),
            new File("target/test-libs/infinispan-commons.jar"),
            new File("target/test-libs/jboss-marshalling.jar"),
            new File("target/test-libs/jboss-marshalling-river.jar"),
            new File("target/test-libs/jboss-logging.jar"),
            new File("target/test-libs/jgroups.jar")
      );

       return war;
   }
}
